California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 99 - EMINENT DOMAIN. LIMITS ON GOVERNMENT ACQUISITION OF OWNER-OCCUPIED RESIDENCE. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287066 | CALIFORNIANS FOR NEIGHBORHOOD PROTECTION: YES ON PROP 99, NO ON PROP 98, A COALITION OF CONSERVATIONISTS, LABOR AND BUSINESS. A SPONSORED COMMITTEE OF THE CA LEAGUE OF CONSERVATION VOTERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306288 | EASTBAY COALITION NO ON 98/YES ON 99 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1285334 | NO 98/YES 99 - A COMMITTEE OF CITY AND COUNTY ASSOCIATIONS, TAXPAYERS AND ENVIRONMENTAL GROUPS, LEAGUE OF CALIFORNIA CITIES, CALIFORNIANS FOR NEIGHBORHOOD PROTECTION, COALITION OF CONSERVATIONISTS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306797 | EVICTION DEFENSE COLLABORATIVE, INC. NO ON 98 YES ON 99 SPONSORED BY THE SAN FRANCISCO FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306845 | OAKLAND RISING NO ON 98 YES ON 99 COMMITTEE SPONSORED BY URBAN HABITAT | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307176 | ASSOCIATION OF COMMUNITY ORGANIZATIONS FOR REFORM NOW (ACORN) VOTES ISSUES COMMITTEE - NO ON 98 AND YES ON 99 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304768 | COMMITTEE TO SAVE RENT CONTROL - NO ON 98/YES ON 99 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304750 | PROTECT SMALL BUSINESS PROPERTY RIGHTS - A PROJECT OF THE NATIONAL FEDERATION OF INDEPENDENT BUSINESS | OPPOSE